@@ -1,7 +1,7 @@
 #include <cstddef>
 #include <apt-front/predicate/combinators.h>
 #include <apt-front/predicate/factory.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <klineedit.h>
 #include "filterwidget.h"
 
