@@ -2,10 +2,10 @@
 #ifndef APP_H
 #define APP_H
 
-#include <kmainwindow.h>
-#include <kparts/part.h>
-#include <kactionclasses.h>
-#include <kcmdlineargs.h>
+#include <tdemainwindow.h>
+#include <tdeparts/part.h>
+#include <tdeactionclasses.h>
+#include <tdecmdlineargs.h>
 #include <apt-front/cache/observer.h>
 #include <apt-front/cache/component/state.h>
 #include <apt-front/cache/component/history.h>
@@ -18,7 +18,7 @@
 class TQVBox;
 class TQWidgetStack;
 class TQSplitter;
-class KAction;
+class TDEAction;
 class KPushButton;
 namespace adept {
 class AcqProgressWidget;
@@ -27,13 +27,13 @@ class AcqProgressWidget;
 using namespace aptFront;
 using namespace adept;
 
-class App : public KMainWindow, Application {
+class App : public TDEMainWindow, Application {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     void setupActions();
     ExtTerminalInterface *terminal();
-	App( KCmdLineArgs *a );
+	App( TDECmdLineArgs *a );
 signals:
   void imDone();
 protected slots:
