@@ -1,28 +1,28 @@
 // KDE includes
  
-#include <kcmdlineargs.h>
-#include <kaboutdata.h>
+#include <tdecmdlineargs.h>
+#include <tdeaboutdata.h>
 #include <kuniqueapplication.h>
 
 #include "app.h"
 
-static KCmdLineOptions options[] =
+static TDECmdLineOptions options[] =
 {
     { "+command", I18N_NOOP("Command"), 0 },
-    KCmdLineLastOption
+    TDECmdLineLastOption
 };
 
 int main(int argc, char *argv[])
 {
-    KLocale::setMainCatalogue("adept");
+    TDELocale::setMainCatalogue("adept");
 
     TQString description = i18n("Adept Batch");
     
-    KAboutData aboutData( "adept_batch", 
+    TDEAboutData aboutData( "adept_batch", 
                           I18N_NOOP("Adept Batch"),
                           "2.1 Cruiser",
                           description.latin1(),
-                          KAboutData::License_BSD,
+                          TDEAboutData::License_BSD,
                           I18N_NOOP("(c) 2006 Peter Rockai"),
                           0,
                           "http://web.mornfall.net/adept.html");
@@ -32,12 +32,12 @@ int main(int argc, char *argv[])
                           "me at mornfall dot net",
                           "http://web.mornfall.net");
 
-    KCmdLineArgs::init( argc, argv, &aboutData );
-    KCmdLineArgs::addCmdLineOptions( options ); 
+    TDECmdLineArgs::init( argc, argv, &aboutData );
+    TDECmdLineArgs::addCmdLineOptions( options ); 
 
-    KApplication app;
-    KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
-    KGlobal::locale()->insertCatalogue(TQString::fromUtf8("libept"));
+    TDEApplication app;
+    TDECmdLineArgs* args = TDECmdLineArgs::parsedArgs();
+    TDEGlobal::locale()->insertCatalogue(TQString::fromUtf8("libept"));
 
     App *ta = new App( args );
 
