@@ -18,12 +18,12 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
  ***************************************************************************/
 #include <kurl.h>
-#include <kio/netaccess.h>
-#include <kio/job.h>
+#include <tdeio/netaccess.h>
+#include <tdeio/job.h>
 #include <kprocess.h>
-#include <klocale.h>
-#include <kglobal.h>
-#include <kconfig.h>
+#include <tdelocale.h>
+#include <tdeglobal.h>
+#include <tdeconfig.h>
 #include <ktar.h>
 #include <kdebug.h>
 
@@ -126,7 +126,7 @@ void UpgradeWizard::removeOldUpgradeTool()
 	// remove old files from dist-upgrade when we check if there is a knew one since
 	// adept kills us before we have a chance on the same run.
 	// Mar-22-2007 Billy Pollifrone
-	TQString directoryName("/tmp/kde-root");
+	TQString directoryName("/tmp/tde-root");
 	TQString directoryFilter("adept_*.tmp*");
 	TQDir dir(directoryName, directoryFilter);
 	TQStringList files(dir.entryList());
@@ -151,7 +151,7 @@ bool UpgradeWizard::checkForDistUpgrade(TQString url, bool developmentVersion) {
 	}
 
 	bool upgrade_available = false;
-	KConfig* config = KGlobal::config();
+	TDEConfig* config = TDEGlobal::config();
 	config->setGroup("General Settings");
         TQString upgradeURL;
         upgradeURL = config->readEntry(TQString("upgradeURL"), url);
@@ -159,19 +159,19 @@ bool UpgradeWizard::checkForDistUpgrade(TQString url, bool developmentVersion) {
 
 	TQString temp_file_location;
 	
-	if( KIO::NetAccess::download( metafile_url, temp_file_location, NULL ) ) {
+	if( TDEIO::NetAccess::download( metafile_url, temp_file_location, NULL ) ) {
 		TQFile temp_file( temp_file_location );
 		temp_file.open(  IO_ReadOnly );
 		TQTextIStream *temp_file_stream = new TQTextIStream( temp_file.readAll() );
 
 		// need to spawn a process to call lsb_release -c -s 
 		// to find out which version of kubuntu we are using
-		KProcess *proc = new KProcess;
+		TDEProcess *proc = new TDEProcess;
 		*proc << "lsb_release";
 		*proc << "-c" << "-s";
-		connect(proc, TQT_SIGNAL( receivedStdout( KProcess*, char *, int )  ),
-				this,	TQT_SLOT( receiveDistroName( KProcess*, char *, int ) ) );
-		proc->start( KProcess::Block, KProcess::Stdout );	
+		connect(proc, TQT_SIGNAL( receivedStdout( TDEProcess*, char *, int )  ),
+				this,	TQT_SLOT( receiveDistroName( TDEProcess*, char *, int ) ) );
+		proc->start( TDEProcess::Block, TDEProcess::Stdout );	
 
 		current_dist = 0;
 		TQPtrList<DistroEntry> *entry_list = parseMetafile( temp_file_stream, distro_name );
@@ -236,7 +236,7 @@ bool UpgradeWizard::checkForDistUpgrade(TQString url, bool developmentVersion) {
 		}
 		*/
 		temp_file.close();
-		KIO::NetAccess::removeTempFile( temp_file_location );
+		TDEIO::NetAccess::removeTempFile( temp_file_location );
 	}
 
 	return upgrade_available;
@@ -390,7 +390,7 @@ TQPtrList<DistroEntry> *UpgradeWizard::parseMetafile( TQTextIStream *text_stream
 
 // ** SLOTS ** //
 
-void UpgradeWizard::receiveDistroName( KProcess*, char *buffer, int buflen ) {
+void UpgradeWizard::receiveDistroName( TDEProcess*, char *buffer, int buflen ) {
 	distro_name = TQString::fromAscii( buffer, buflen-1 );
 }
 
@@ -404,11 +404,11 @@ void UpgradeWizard::launchDistUpdater() {
 	//tarDirectory->copyTo(upgrade_tool_location+"-extract");
 	tarFile.directory()->copyTo(upgrade_tool_location+"-extract", true);
 
-	KProcess *proc = new KProcess;
+	TDEProcess *proc = new TDEProcess;
 	proc->setWorkingDirectory(upgrade_tool_location+"-extract");
 	*proc << "python" << upgrade_tool_location+"-extract/dist-upgrade.py";
 	*proc << "--frontend" << "DistUpgradeViewKDE";
-	proc->start( KProcess::DontCare );
+	proc->start( TDEProcess::DontCare );
 
 	// don't kill adept, it stops the app from running
 	// parentWidget()->close();	
@@ -422,7 +422,7 @@ void UpgradeWizard::fetchReleaseAnnounce() {
     kdDebug() << "No release notes URL, so I'm skipping the fetch." << endl;
   } else {
     KURL my_url(*upgrade_dist->release_notes_url);
-    result = KIO::NetAccess::download(my_url, temp_file_location, NULL );
+    result = TDEIO::NetAccess::download(my_url, temp_file_location, NULL );
   }
 
 	if( result ) {
@@ -447,9 +447,9 @@ void UpgradeWizard::fetchReleaseAnnounce() {
 void UpgradeWizard::fetchUpgradeTool() {
 	// download the upgrade tool
         KURL my_url(*upgrade_dist->upgrade_tool_url);
-	bool result = KIO::NetAccess::download( my_url, upgrade_tool_location, NULL );
+	bool result = TDEIO::NetAccess::download( my_url, upgrade_tool_location, NULL );
 	// uncomment this to use for testing if you don't want to d/l the file every time
-	//bool result = KIO::NetAccess::download( "/home/vladi/edgy.tar.gz", upgrade_tool_location, NULL );
+	//bool result = TDEIO::NetAccess::download( "/home/vladi/edgy.tar.gz", upgrade_tool_location, NULL );
 	if( result ) {
 		emit killErrorDialog();
 		err_dlg = NULL;
@@ -467,7 +467,7 @@ void UpgradeWizard::fetchUpgradeTool() {
 }
 
 void UpgradeWizard::fetchUpgradeToolSig() {
-	bool result = KIO::NetAccess::download( *upgrade_dist->upgrade_tool_sig_url, upgrade_tool_sig_location, NULL );
+	bool result = TDEIO::NetAccess::download( *upgrade_dist->upgrade_tool_sig_url, upgrade_tool_sig_location, NULL );
 	if( result) {
 		emit killErrorDialog();
 		err_dlg = NULL;
@@ -486,17 +486,17 @@ void UpgradeWizard::fetchUpgradeToolSig() {
 
 void UpgradeWizard::verifyUpgradeTool() {
 	// spawn a process to call gpg and verify the signature
-	KProcess *proc = new KProcess;
+	TDEProcess *proc = new TDEProcess;
 	*proc << "gpg";
 	*proc << "--keyring" << "/etc/apt/trusted.gpg" << "--verify" << upgrade_tool_sig_location << upgrade_tool_location;
 		
-	proc->start( KProcess::Block, KProcess::Stdout );		
+	proc->start( TDEProcess::Block, TDEProcess::Stdout );		
 	// signature verification successful if gpg exist status = 0
 	if( proc->exitStatus() == 0 ) {
 		emit killErrorDialog();
 		err_dlg = NULL;
 		// remove the signature file
-		KIO::file_delete( KURL( upgrade_tool_sig_location ), false );
+		TDEIO::file_delete( KURL( upgrade_tool_sig_location ), false );
 		TQWidget *p = page( pageCount()-1 );
 		setFinishEnabled( p, true );
 		textLabel3->show();
@@ -529,7 +529,7 @@ void UpgradeWizard::next()
 	}
 	else if( indexOf( currentPage() ) == 2 ) {
 		// remove the temp file used to store the release announcement
-		KIO::file_delete( KURL( textBrowser1->source() ), false );
+		TDEIO::file_delete( KURL( textBrowser1->source() ), false );
 
 		// download the tool, its signature, and verify
 		fetchUpgradeTool();
