@@ -6,12 +6,12 @@
 #include <tqthread.h>
 #include <tqtextbrowser.h>
 
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 #include <kdebug.h>
 #include <klineedit.h>
-#include <klocale.h>
-#include <kapplication.h>
-#include <kglobal.h>
+#include <tdelocale.h>
+#include <tdeapplication.h>
+#include <tdeglobal.h>
 #include <kiconloader.h>
 
 #include <functional>
@@ -406,7 +406,7 @@ void ListerItem::paintCell (TQPainter *p, const TQColorGroup &cg,
             c = actionColor( p );
     }
     _cg.setColor( TQColorGroup::Text, c );
-    KListViewItem::paintCell( &_p, _cg, column, width, AlignTop );
+    TDEListViewItem::paintCell( &_p, _cg, column, width, AlignTop );
     p->drawPixmap( 0, 0, pm );
 }
 
@@ -417,7 +417,7 @@ void Lister::contextMenu( TQListViewItem *it, const TQPoint &pt, int /*c*/ )
     m_context = dynamic_cast< ListerItem * >( it );
     VectorRange sel = selection();
     // entity::Package p = (dynamic_cast<ListerItem *>(it)->entity());
-    KPopupMenu *m = new KPopupMenu (this);
+    TDEPopupMenu *m = new TDEPopupMenu (this);
     utils::Range< Actor > r = actor::Global< entity::Package >::list();
     int id = 8;
     try {
