@@ -1,29 +1,29 @@
 // KDE includes
 
-#include <kcmdlineargs.h>
-#include <kaboutdata.h>
+#include <tdecmdlineargs.h>
+#include <tdeaboutdata.h>
 #include <kuniqueapplication.h>
 
 #include "app.h"
 
-static KCmdLineOptions options[] =
+static TDECmdLineOptions options[] =
 {
-    KCmdLineLastOption
+    TDECmdLineLastOption
 };
 
 int main(int argc, char *argv[])
 {
 
-    KLocale::setMainCatalogue("adept_updater");
+    TDELocale::setMainCatalogue("adept_updater");
 
     putenv( "TQT_IM_MODULE=xim" );
     TQString description = i18n("Adept Updater");
 
-    KAboutData aboutData( "adept_updater",
+    TDEAboutData aboutData( "adept_updater",
                           I18N_NOOP("Adept Updater"),
                           "2.1 Cruiser",
                           description.latin1(),
-                          KAboutData::License_BSD,
+                          TDEAboutData::License_BSD,
                           I18N_NOOP("(c) 2005, 2006 Peter Rockai"),
                           0,
                           "http://web.mornfall.net/adept.html");
@@ -33,19 +33,19 @@ int main(int argc, char *argv[])
                           "me at mornfall dot net",
                           "http://web.mornfall.net");
 
-    KCmdLineArgs::init( argc, argv, &aboutData );
-    KCmdLineArgs::addCmdLineOptions( options );
+    TDECmdLineArgs::init( argc, argv, &aboutData );
+    TDECmdLineArgs::addCmdLineOptions( options );
 
-    KApplication app;
+    TDEApplication app;
 
-    KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
+    TDECmdLineArgs* args = TDECmdLineArgs::parsedArgs();
     // if (args && args->isSet("xy")) ...
 
-    /* KConfig* config = KGlobal::config();
+    /* TDEConfig* config = TDEGlobal::config();
     config->setGroup("General Settings");
     TQString version = config->readEntry("Version"); */
 
-    KGlobal::locale()->insertCatalogue(TQString::fromUtf8("libept"));
+    TDEGlobal::locale()->insertCatalogue(TQString::fromUtf8("libept"));
 
     TestApp *ta = new TestApp();
 
